@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2023-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the Software), to deal
@@ -33,14 +33,10 @@ extern "C" {
 #endif
 
 /*! \ingroup precond_module
-*  \brief Incomplete LU factorization with 0 fill-ins and no pivoting using CSR
-*  storage format
-*
 *  \details
 *  \p rocsparse_csrilu0_zero_pivot returns \ref rocsparse_status_zero_pivot, if either a
-*  structural or numerical zero has been found during rocsparse_scsrilu0(),
-*  rocsparse_dcsrilu0(), rocsparse_ccsrilu0() or rocsparse_zcsrilu0() computation. The
-*  first zero pivot \f$j\f$ at \f$A_{j,j}\f$ is stored in \p position, using same index
+*  structural or numerical zero has been found during \ref rocsparse_scsrilu0 "rocsparse_Xcsrilu0()"
+*  computation. The first zero pivot \f$j\f$ at \f$A_{j,j}\f$ is stored in \p position, using same index
 *  base as the CSR matrix.
 *
 *  \p position can be in host or device memory. If no zero pivot has been found,
@@ -72,9 +68,100 @@ rocsparse_status rocsparse_csrilu0_zero_pivot(rocsparse_handle   handle,
                                               rocsparse_int*     position);
 
 /*! \ingroup precond_module
- *  \brief Incomplete LU factorization with 0 fill-ins and no pivoting using CSR storage
- *  format
- *
+*  \details
+*  \p rocsparse_csrilu0_set_tolerance() sets the numerical tolerance for detecting a
+*  near numerical zero entry during \ref rocsparse_scsrilu0 "rocsparse_Xcsrilu0()"
+*  computation. The first singular pivot \f$j\f$ at \f$|A_{j,j}| \leq \text{tolerance}\f$.
+*
+*
+*  \note \p rocsparse_csrilu0_set_tolerance() is a blocking function. It might influence
+*  performance negatively.
+*
+*  \note
+*  This routine does not support execution in a hipGraph context.
+*
+*  @param[in]
+*  handle      handle to the rocsparse library context queue.
+*  @param[in]
+*  info        structure that holds the information collected during the analysis step.
+*  @param[in]
+*  tolerance    tolerance value to determine singular pivot \f$|A_{j,j}| \leq \text{tolerance}\f$,
+*               where variable tolerance is in host memory.
+*
+*  \retval     rocsparse_status_success the operation completed successfully.
+*  \retval     rocsparse_status_invalid_handle the library context was not initialized.
+*  \retval     rocsparse_status_invalid_pointer \p info pointer is invalid.
+*  \retval     rocsparse_status_internal_error an internal error occurred.
+*/
+ROCSPARSE_EXPORT
+rocsparse_status rocsparse_csrilu0_set_tolerance(rocsparse_handle   handle,
+                                                 rocsparse_mat_info info,
+                                                 double             tolerance);
+
+/*! \ingroup precond_module
+*  \details
+*  \p rocsparse_csrilu0_get_tolerance() returns the numerical tolerance for detecing
+*  a near numerical zero entry during \ref rocsparse_scsrilu0 "rocsparse_Xcsrilu0()"
+*  computation. The first singular pivot \f$j\f$ at \f$|A_{j,j}| \leq \text{tolerance}\f$.
+*
+*  \note \p rocsparse_csrilu0_get_tolerance() is a blocking function. It might influence
+*  performance negatively.
+*
+*  \note
+*  This routine does not support execution in a hipGraph context.
+*
+*  @param[in]
+*  handle      handle to the rocsparse library context queue.
+*  @param[in]
+*  info        structure that holds the information collected during the analysis step.
+*  @param[out]
+*  tolerance   obtain tolerance value to determine singular pivot \f$|A_{j,j}| \leq \text{tolerance}\f$,
+*              where variable tolerance is in host memory.
+*
+*  \retval     rocsparse_status_success the operation completed successfully.
+*  \retval     rocsparse_status_invalid_handle the library context was not initialized.
+*  \retval     rocsparse_status_invalid_pointer \p info or tolerance pointer is invalid..
+*  \retval     rocsparse_status_internal_error an internal error occurred.
+*/
+ROCSPARSE_EXPORT
+rocsparse_status rocsparse_csrilu0_get_tolerance(rocsparse_handle   handle,
+                                                 rocsparse_mat_info info,
+                                                 double*            tolerance);
+/*! \ingroup precond_module
+*  \details
+*  \p rocsparse_csrilu0_singular_pivot() returns the position of a
+*  near numerical zero entry that has been found during \ref rocsparse_scsrilu0 "rocsparse_Xcsrilu0()"
+*  computation. The first singular pivot \f$j\f$ at \f$|A_{j,j}| \leq \text{tolerance}\f$  is stored
+*  in \p position, using same index base as the CSR matrix.
+*
+*  \p position can be in host or device memory. If no singular pivot has been found,
+*  \p position is set to -1.
+*
+*  \note \p rocsparse_csrilu0_singular_pivot() is a blocking function. It might influence
+*  performance negatively.
+*
+*  \note
+*  This routine does not support execution in a hipGraph context.
+*
+*  @param[in]
+*  handle      handle to the rocsparse library context queue.
+*  @param[in]
+*  info        structure that holds the information collected during the analysis step.
+*  @param[inout]
+*  position    pointer to singular pivot \f$j\f$, can be in host or device memory.
+*
+*  \retval     rocsparse_status_success the operation completed successfully.
+*  \retval     rocsparse_status_invalid_handle the library context was not initialized.
+*  \retval     rocsparse_status_invalid_pointer \p info or \p position pointer is
+*              invalid.
+*  \retval     rocsparse_status_internal_error an internal error occurred.
+*/
+ROCSPARSE_EXPORT
+rocsparse_status rocsparse_csrilu0_singular_pivot(rocsparse_handle   handle,
+                                                  rocsparse_mat_info info,
+                                                  rocsparse_int*     position);
+
+/*! \ingroup precond_module
  *  \details
  *  \p rocsparse_csrilu0_numeric_boost enables the user to replace a numerical value in
  *  an incomplete LU factorization. \p tol is used to determine whether a numerical value
@@ -155,19 +242,13 @@ rocsparse_status rocsparse_dccsrilu0_numeric_boost(rocsparse_handle
 /**@}*/
 
 /*! \ingroup precond_module
-*  \brief Incomplete LU factorization with 0 fill-ins and no pivoting using CSR
-*  storage format
-*
 *  \details
 *  \p rocsparse_csrilu0_buffer_size returns the size of the temporary storage buffer
-*  that is required by rocsparse_scsrilu0_analysis(), rocsparse_dcsrilu0_analysis(),
-*  rocsparse_ccsrilu0_analysis(), rocsparse_zcsrilu0_analysis(), rocsparse_scsrilu0(),
-*  rocsparse_dcsrilu0(), rocsparse_ccsrilu0() and rocsparse_zcsrilu0(). The temporary
-*  storage buffer must be allocated by the user. The size of the temporary storage
-*  buffer is identical to the size returned by rocsparse_scsrsv_buffer_size(),
-*  rocsparse_dcsrsv_buffer_size(), rocsparse_ccsrsv_buffer_size() and
-*  rocsparse_zcsrsv_buffer_size() if the matrix sparsity pattern is identical. The user
-*  allocated buffer can thus be shared between subsequent calls to those functions.
+*  that is required by \ref rocsparse_scsrilu0_analysis "rocsparse_Xcsrilu0_analysis()" and
+*  \ref rocsparse_scsrilu0 "rocsparse_Xcsrilu0()". The temporary storage buffer must be allocated
+*  by the user. The size of the temporary storage buffer is identical to the size returned by
+*  \ref rocsparse_scsrsv_buffer_size "rocsparse_Xcsrsv_buffer_size()" if the matrix sparsity pattern
+*  is identical. The user allocated buffer can thus be shared between subsequent calls to those functions.
 *
 *  \note
 *  This function is non blocking and executed asynchronously with respect to the host.
@@ -196,10 +277,8 @@ rocsparse_status rocsparse_dccsrilu0_numeric_boost(rocsparse_handle
 *  info        structure that holds the information collected during the analysis step.
 *  @param[out]
 *  buffer_size number of bytes of the temporary storage buffer required by
-*              rocsparse_scsrilu0_analysis(), rocsparse_dcsrilu0_analysis(),
-*              rocsparse_ccsrilu0_analysis(), rocsparse_zcsrilu0_analysis(),
-*              rocsparse_scsrilu0(), rocsparse_dcsrilu0(), rocsparse_ccsrilu0() and
-*              rocsparse_zcsrilu0().
+*              \ref rocsparse_scsrilu0_analysis "rocsparse_Xcsrilu0_analysis()" and
+*              \ref rocsparse_scsrilu0 "rocsparse_Xcsrilu0()".
 *
 *  \retval     rocsparse_status_success the operation completed successfully.
 *  \retval     rocsparse_status_invalid_handle the library context was not initialized.
@@ -208,7 +287,6 @@ rocsparse_status rocsparse_dccsrilu0_numeric_boost(rocsparse_handle
 *              \p csr_col_ind, \p info or \p buffer_size pointer is invalid.
 *  \retval     rocsparse_status_internal_error an internal error occurred.
 *  \retval     rocsparse_status_not_implemented
-*              \p trans != \ref rocsparse_operation_none or
 *              \ref rocsparse_matrix_type != \ref rocsparse_matrix_type_general.
 */
 /**@{*/
@@ -258,24 +336,17 @@ rocsparse_status rocsparse_zcsrilu0_buffer_size(rocsparse_handle
 /**@}*/
 
 /*! \ingroup precond_module
-*  \brief Incomplete LU factorization with 0 fill-ins and no pivoting using CSR
-*  storage format
-*
 *  \details
-*  \p rocsparse_csrilu0_analysis performs the analysis step for rocsparse_scsrilu0(),
-*  rocsparse_dcsrilu0(), rocsparse_ccsrilu0() and rocsparse_zcsrilu0(). It is expected
-*  that this function will be executed only once for a given matrix and particular
-*  operation type. The analysis meta data can be cleared by rocsparse_csrilu0_clear().
+*  \p rocsparse_csrilu0_analysis performs the analysis step for \ref rocsparse_scsrilu0 "rocsparse_Xcsrilu0()".
+*  It is expected that this function will be executed only once for a given matrix and particular
+*  operation type. The analysis meta data can be cleared by \ref rocsparse_csrilu0_clear().
 *
 *  \p rocsparse_csrilu0_analysis can share its meta data with
-*  rocsparse_scsric0_analysis(), rocsparse_dcsric0_analysis(),
-*  rocsparse_ccsric0_analysis(), rocsparse_zcsric0_analysis(),
-*  rocsparse_scsrsv_analysis(), rocsparse_dcsrsv_analysis(),
-*  rocsparse_ccsrsv_analysis(), rocsparse_zcsrsv_analysis(),
-*  rocsparse_scsrsm_analysis(), rocsparse_dcsrsm_analysis(),
-*  rocsparse_scsrsm_analysis() and rocsparse_dcsrsm_analysis(). Selecting
+*  \ref rocsparse_scsric0_analysis "rocsparse_Xcsric0_analysis()",
+*  \ref rocsparse_scsrsv_analysis "rocsparse_Xcsrsv_analysis()", and
+*  \ref rocsparse_scsrsm_analysis "rocsparse_Xcsrsm_analysis()". Selecting
 *  \ref rocsparse_analysis_policy_reuse policy can greatly improve computation
-*  performance of meta data. However, the user need to make sure that the sparsity
+*  performance of meta data. However, the user needs to make sure that the sparsity
 *  pattern remains unchanged. If this cannot be assured,
 *  \ref rocsparse_analysis_policy_force has to be used.
 *
@@ -322,7 +393,6 @@ rocsparse_status rocsparse_zcsrilu0_buffer_size(rocsparse_handle
 *              \p csr_col_ind, \p info or \p temp_buffer pointer is invalid.
 *  \retval     rocsparse_status_internal_error an internal error occurred.
 *  \retval     rocsparse_status_not_implemented
-*              \p trans != \ref rocsparse_operation_none or
 *              \ref rocsparse_matrix_type != \ref rocsparse_matrix_type_general.
 */
 /**@{*/
@@ -380,20 +450,16 @@ rocsparse_status rocsparse_zcsrilu0_analysis(rocsparse_handle                han
 /**@}*/
 
 /*! \ingroup precond_module
-*  \brief Incomplete LU factorization with 0 fill-ins and no pivoting using CSR
-*  storage format
-*
 *  \details
 *  \p rocsparse_csrilu0_clear deallocates all memory that was allocated by
-*  rocsparse_scsrilu0_analysis(), rocsparse_dcsrilu0_analysis(),
-*  rocsparse_ccsrilu0_analysis() or rocsparse_zcsrilu0_analysis(). This is especially
+*  \ref rocsparse_scsrilu0_analysis "rocsparse_Xcsrilu0_analysis()". This is especially
 *  useful, if memory is an issue and the analysis data is not required for further
 *  computation.
 *
 *  \note
 *  Calling \p rocsparse_csrilu0_clear is optional. All allocated resources will be
 *  cleared, when the opaque \ref rocsparse_mat_info struct is destroyed using
-*  rocsparse_destroy_mat_info().
+*  \ref rocsparse_destroy_mat_info().
 *
 *  \note
 *  This routine does not support execution in a hipGraph context.
@@ -423,15 +489,85 @@ rocsparse_status rocsparse_csrilu0_clear(rocsparse_handle handle, rocsparse_mat_
 *  \f[
 *    A \approx LU
 *  \f]
+*  where the lower triangular matrix \f$L\f$ and the upper triangular matrix \f$U\f$ are computed using:
+*  \f[
+*    \begin{array}{ll}
+*        L_{ij} = \frac{1}{U_{jj}}(A_{ij} - \sum_{k=0}^{j-1}L_{ik} \times U_{kj}), & \text{if i > j} \\
+*        U_{ij} = (A_{ij} - \sum_{k=0}^{j-1}L_{ik} \times U_{kj}), & \text{if i <= j}
+*    \end{array}
+*  \f]
+*  for each entry found in the CSR matrix \f$A\f$.
 *
-*  \p rocsparse_csrilu0 requires a user allocated temporary buffer. Its size is returned
-*  by rocsparse_scsrilu0_buffer_size(), rocsparse_dcsrilu0_buffer_size(),
-*  rocsparse_ccsrilu0_buffer_size() or rocsparse_zcsrilu0_buffer_size(). Furthermore,
-*  analysis meta data is required. It can be obtained by rocsparse_scsrilu0_analysis(),
-*  rocsparse_dcsrilu0_analysis(), rocsparse_ccsrilu0_analysis() or
-*  rocsparse_zcsrilu0_analysis(). \p rocsparse_csrilu0 reports the first zero pivot
-*  (either numerical or structural zero). The zero pivot status can be obtained by
-*  calling rocsparse_csrilu0_zero_pivot().
+*  Computing the above incomplete \f$LU\f$ factorization requires three steps to complete. First,
+*  the user determines the size of the required temporary storage buffer by calling
+*  \ref rocsparse_scsrilu0_buffer_size "rocsparse_Xcsrilu0_buffer_size()". Once this buffer size has been determined,
+*  the user allocates the buffer and passes it to \ref rocsparse_scsrilu0_analysis "rocsparse_Xcsrilu0_analysis()".
+*  This will perform analysis on the sparsity pattern of the matrix. Finally, the user calls \p rocsparse_scsrilu0,
+*  \p rocsparse_dcsrilu0, \p rocsparse_ccsrilu0, or \p rocsparse_zcsrilu0 to perform the actual factorization. The calculation
+*  of the buffer size and the analysis of the sparse matrix only need to be performed once for a given sparsity pattern
+*  while the factorization can be repeatedly applied to multiple matrices having the same sparsity pattern. Once all calls
+*  to \ref rocsparse_scsrilu0 "rocsparse_Xcsrilu0()" are complete, the temporary buffer can be deallocated.
+*
+*  When computing the \f$LU\f$ factorization, it is possible that \f$U_{jj} == 0\f$ which would result in a division by zero.
+*  This could occur from either \f$A_{jj}\f$ not existing in the sparse CSR matrix (referred to as a structural zero) or because
+*  \f$A_{ij} - \sum_{k=0}^{j-1}L_{ik} \times U_{kj} == 0\f$ (referred to as a numerical zero). For example, running the
+*  \f$LU\f$ factorization on the following matrix:
+*  \f[
+*    \begin{bmatrix}
+*    2 & 1 & 0 \\
+*    1 & 2 & 1 \\
+*    0 & 1 & 2
+*    \end{bmatrix}
+*  \f]
+*  results in a successful \f$LU\f$ factorization, however running with the matrix:
+*  \f[
+*    \begin{bmatrix}
+*    2 & 1 & 0 \\
+*    1 & 1/2 & 1 \\
+*    0 & 1 & 2
+*    \end{bmatrix}
+*  \f]
+*  results in a numerical zero because:
+*  \f[
+*    \begin{array}{ll}
+*        U_{00} &= 2 \\
+*        U_{01} &= 1 \\
+*        L_{10} &= \frac{1}{2} \\
+*        U_{11} &= \frac{1}{2} - \frac{1}{2}
+*               &= 0
+*    \end{array}
+*  \f]
+*  The user can detect the presence of a structural zero by calling \ref rocsparse_csrilu0_zero_pivot() after
+*  \ref rocsparse_scsrilu0_analysis "rocsparse_Xcsrilu0_analysis()" and/or the presence of a structural or
+*  numerical zero by calling \ref rocsparse_csrilu0_zero_pivot() after \ref rocsparse_scsrilu0 "rocsparse_Xcsric0()".
+*  In both cases, \ref rocsparse_csrilu0_zero_pivot() will report the first zero pivot (either numerical or structural)
+*  found. See example below. The user can also set the diagonal type to be \f$1\f$ using \ref rocsparse_set_mat_diag_type()
+*  which will interpret the matrix \f$A\f$ as having ones on its diagonal (even if no nonzero exists in the sparsity pattern).
+*
+*  \p rocsparse_csrilu0 computes the \f$LU\f$ factorization inplace meaning that the values array \p csr_val of the \f$A\f$
+*  matrix is overwritten with the \f$L\f$ matrix stored in the strictly lower triangular part of \f$A\f$ and the \f$U\f$ matrix
+*  stored in the upper part of \f$A\f$:
+*
+*  \f[
+*    \begin{align}
+*    \begin{bmatrix}
+*    a_{00} & a_{01} & a_{02} \\
+*    a_{10} & a_{11} & a_{12} \\
+*    a_{20} & a_{21} & a_{22}
+*    \end{bmatrix}
+*    \rightarrow
+*    \begin{bmatrix}
+*    u_{00} & u_{01} & u_{02} \\
+*    l_{10} & u_{11} & u_{12} \\
+*    l_{20} & l_{21} & u_{22}
+*    \end{bmatrix}
+*    \end{align}
+*  \f]
+*  The row pointer array \p csr_row_ptr and the column indices array \p csr_col_ind remain the same for \f$A\f$ and \f$LU\f$ as
+*  the incomplete factorization does not generate new nonzeros in \f$LU\f$ which do not already exist in \f$A\f$.
+*
+*  The performance of computing \f$LU\f$ factorization with rocSPARSE greatly depends on the sparisty pattern
+*  the the matrix \f$A\f$ as this is what determines the amount of parallelism available.
 *
 *  \note
 *  The sparse CSR matrix has to be sorted. This can be achieved by calling
@@ -475,187 +611,13 @@ rocsparse_status rocsparse_csrilu0_clear(rocsparse_handle handle, rocsparse_mat_
 *  \retval     rocsparse_status_arch_mismatch the device is not supported.
 *  \retval     rocsparse_status_internal_error an internal error occurred.
 *  \retval     rocsparse_status_not_implemented
-*              \p trans != \ref rocsparse_operation_none or
 *              \ref rocsparse_matrix_type != \ref rocsparse_matrix_type_general.
 *
 *  \par Example
 *  Consider the sparse \f$m \times m\f$ matrix \f$A\f$, stored in CSR
 *  storage format. The following example computes the incomplete LU factorization
 *  \f$M \approx LU\f$ and solves the preconditioned system \f$My = x\f$.
-*  \code{.c}
-*      // Create rocSPARSE handle
-*      rocsparse_handle handle;
-*      rocsparse_create_handle(&handle);
-*
-*      // Create matrix descriptor for M
-*      rocsparse_mat_descr descr_M;
-*      rocsparse_create_mat_descr(&descr_M);
-*
-*      // Create matrix descriptor for L
-*      rocsparse_mat_descr descr_L;
-*      rocsparse_create_mat_descr(&descr_L);
-*      rocsparse_set_mat_fill_mode(descr_L, rocsparse_fill_mode_lower);
-*      rocsparse_set_mat_diag_type(descr_L, rocsparse_diag_type_unit);
-*
-*      // Create matrix descriptor for U
-*      rocsparse_mat_descr descr_U;
-*      rocsparse_create_mat_descr(&descr_U);
-*      rocsparse_set_mat_fill_mode(descr_U, rocsparse_fill_mode_upper);
-*      rocsparse_set_mat_diag_type(descr_U, rocsparse_diag_type_non_unit);
-*
-*      // Create matrix info structure
-*      rocsparse_mat_info info;
-*      rocsparse_create_mat_info(&info);
-*
-*      // Obtain required buffer size
-*      size_t buffer_size_M;
-*      size_t buffer_size_L;
-*      size_t buffer_size_U;
-*      rocsparse_dcsrilu0_buffer_size(handle,
-*                                    m,
-*                                    nnz,
-*                                    descr_M,
-*                                    csr_val,
-*                                    csr_row_ptr,
-*                                    csr_col_ind,
-*                                    info,
-*                                    &buffer_size_M);
-*      rocsparse_dcsrsv_buffer_size(handle,
-*                                   rocsparse_operation_none,
-*                                   m,
-*                                   nnz,
-*                                   descr_L,
-*                                   csr_val,
-*                                   csr_row_ptr,
-*                                   csr_col_ind,
-*                                   info,
-*                                   &buffer_size_L);
-*      rocsparse_dcsrsv_buffer_size(handle,
-*                                   rocsparse_operation_none,
-*                                   m,
-*                                   nnz,
-*                                   descr_U,
-*                                   csr_val,
-*                                   csr_row_ptr,
-*                                   csr_col_ind,
-*                                   info,
-*                                   &buffer_size_U);
-*
-*      size_t buffer_size = max(buffer_size_M, max(buffer_size_L, buffer_size_U));
-*
-*      // Allocate temporary buffer
-*      void* temp_buffer;
-*      hipMalloc(&temp_buffer, buffer_size);
-*
-*      // Perform analysis steps, using rocsparse_analysis_policy_reuse to improve
-*      // computation performance
-*      rocsparse_dcsrilu0_analysis(handle,
-*                                  m,
-*                                  nnz,
-*                                  descr_M,
-*                                  csr_val,
-*                                  csr_row_ptr,
-*                                  csr_col_ind,
-*                                  info,
-*                                  rocsparse_analysis_policy_reuse,
-*                                  rocsparse_solve_policy_auto,
-*                                  temp_buffer);
-*      rocsparse_dcsrsv_analysis(handle,
-*                                rocsparse_operation_none,
-*                                m,
-*                                nnz,
-*                                descr_L,
-*                                csr_val,
-*                                csr_row_ptr,
-*                                csr_col_ind,
-*                                info,
-*                                rocsparse_analysis_policy_reuse,
-*                                rocsparse_solve_policy_auto,
-*                                temp_buffer);
-*      rocsparse_dcsrsv_analysis(handle,
-*                                rocsparse_operation_none,
-*                                m,
-*                                nnz,
-*                                descr_U,
-*                                csr_val,
-*                                csr_row_ptr,
-*                                csr_col_ind,
-*                                info,
-*                                rocsparse_analysis_policy_reuse,
-*                                rocsparse_solve_policy_auto,
-*                                temp_buffer);
-*
-*      // Check for zero pivot
-*      rocsparse_int position;
-*      if(rocsparse_status_zero_pivot == rocsparse_csrilu0_zero_pivot(handle,
-*                                                                     info,
-*                                                                     &position))
-*      {
-*          printf("A has structural zero at A(%d,%d)\n", position, position);
-*      }
-*
-*      // Compute incomplete LU factorization
-*      rocsparse_dcsrilu0(handle,
-*                         m,
-*                         nnz,
-*                         descr_M,
-*                         csr_val,
-*                         csr_row_ptr,
-*                         csr_col_ind,
-*                         info,
-*                         rocsparse_solve_policy_auto,
-*                         temp_buffer);
-*
-*      // Check for zero pivot
-*      if(rocsparse_status_zero_pivot == rocsparse_csrilu0_zero_pivot(handle,
-*                                                                     info,
-*                                                                     &position))
-*      {
-*          printf("U has structural and/or numerical zero at U(%d,%d)\n",
-*                 position,
-*                 position);
-*      }
-*
-*      // Solve Lz = x
-*      rocsparse_dcsrsv_solve(handle,
-*                             rocsparse_operation_none,
-*                             m,
-*                             nnz,
-*                             &alpha,
-*                             descr_L,
-*                             csr_val,
-*                             csr_row_ptr,
-*                             csr_col_ind,
-*                             info,
-*                             x,
-*                             z,
-*                             rocsparse_solve_policy_auto,
-*                             temp_buffer);
-*
-*      // Solve Uy = z
-*      rocsparse_dcsrsv_solve(handle,
-*                             rocsparse_operation_none,
-*                             m,
-*                             nnz,
-*                             &alpha,
-*                             descr_U,
-*                             csr_val,
-*                             csr_row_ptr,
-*                             csr_col_ind,
-*                             info,
-*                             z,
-*                             y,
-*                             rocsparse_solve_policy_auto,
-*                             temp_buffer);
-*
-*      // Clean up
-*      hipFree(temp_buffer);
-*      rocsparse_destroy_mat_info(info);
-*      rocsparse_destroy_mat_descr(descr_M);
-*      rocsparse_destroy_mat_descr(descr_L);
-*      rocsparse_destroy_mat_descr(descr_U);
-*      rocsparse_destroy_handle(handle);
-*  \endcode
+*  \snippet example_rocsparse_csrilu0.cpp doc example
 */
 /**@{*/
 ROCSPARSE_EXPORT
