@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2025 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,7 +29,9 @@
 #define ROCSPARSE_TYPES_H
 
 #include "rocsparse-complex-types.h"
+#include "rocsparse_bfloat16.h"
 
+#include <float.h>
 #include <stddef.h>
 #include <stdint.h>
 
@@ -42,7 +44,9 @@
 /// \endcond
 
 /*! \ingroup types_module
- *  \brief Specifies whether int32 or int64 is used.
+ *  \brief Specifies rocSPARSE integer type (defaults to int32_t).
+ *
+ *  \note When rocSPARSE is built with rocsparse_ILP64, \ref rocsparse_int is typedef to int64_t.
  */
 #if defined(rocsparse_ILP64)
 typedef int64_t rocsparse_int;
@@ -66,6 +70,16 @@ typedef struct ihipStream_t* hipStream_t;
  */
 typedef struct _rocsparse_handle* rocsparse_handle;
 
+/*! \ingroup types_module
+ *  \brief Descriptor of the error.
+ *
+ *  \details
+ *  The rocSPARSE error descriptor is a structure holding the information related to an error
+ *  that occured during the execution of a rocSPARSE routine.
+ *  It should be destroyed using rocsparse_destroy_error().
+ */
+typedef struct _rocsparse_error* rocsparse_error;
+
 /*! \ingroup types_module
  *  \brief Descriptor of the matrix.
  *
@@ -118,7 +132,7 @@ typedef struct _rocsparse_spvec_descr* rocsparse_spvec_descr;
  *
  *  \details
  *  The rocSPARSE constant sparse vector descriptor is a structure holding all properties of a sparse vector.
- *  It must be initialized using rocsparse_create_const_spvec_descr() and the returned
+ *  It must be initialized using \ref rocsparse_create_const_spvec_descr() and the returned
  *  descriptor must be passed to all subsequent generic API library calls that involve the sparse vector.
  *  It should be destroyed at the end using rocsparse_destroy_spvec_descr().
  */
@@ -142,7 +156,7 @@ typedef struct _rocsparse_spmat_descr* rocsparse_spmat_descr;
  *
  *  \details
  *  The rocSPARSE constant sparse matrix descriptor is a structure holding all properties of a sparse matrix.
- *  It must be initialized using rocsparse_create__constcoo_descr(), rocsparse_create_const_bsr_descr(),
+ *  It must be initialized using rocsparse_create_const_coo_descr(),
  *  rocsparse_create_const_csr_descr(), rocsparse_create_const_csc_descr(),
  *  or rocsparse_create_const_bell_descr() and the returned
  *  descriptor must be passed to all subsequent generic API library calls that involve the sparse matrix.
@@ -207,6 +221,54 @@ typedef struct _rocsparse_dnmat_descr const* rocsparse_const_dnmat_descr;
  */
 typedef struct _rocsparse_color_info* rocsparse_color_info;
 
+/*! \ingroup types_module
+ * \brief rocsparse_sparse_to_sparse_descr is a structure holding the rocsparse sparse_to_sparse
+ * descr data. It must be initialized using
+ * the rocsparse_create_sparse_to_sparse_descr() routine. It should be destroyed at the
+ * end using rocsparse_destroy_sparse_to_sparse_descr().
+ */
+typedef struct _rocsparse_sparse_to_sparse_descr* rocsparse_sparse_to_sparse_descr;
+
+/*! \ingroup types_module
+ * \brief rocsparse_extract_descr is a structure holding the rocsparse extract
+ * descr data. It must be initialized using
+ * the rocsparse_create_extract_descr() routine. It should be destroyed at the
+ * end using rocsparse_destroy_extract_descr().
+ */
+typedef struct _rocsparse_extract_descr* rocsparse_extract_descr;
+
+/*! \ingroup types_module
+ * \brief rocsparse_spgeam_descr is a structure holding the rocsparse spgeam
+ * descr data. It must be initialized using
+ * the rocsparse_create_spgeam_descr() routine. It should be destroyed at the
+ * end using rocsparse_destroy_spgeam_descr().
+ */
+typedef struct _rocsparse_spgeam_descr* rocsparse_spgeam_descr;
+
+/*! \ingroup types_module
+ * \brief rocsparse_spmv_descr is a structure holding the rocsparse spmv
+ * descr data. It must be initialized using
+ * the rocsparse_create_spmv_descr() routine. It should be destroyed at the
+ * end using rocsparse_destroy_spmv_descr().
+ */
+typedef struct _rocsparse_spmv_descr* rocsparse_spmv_descr;
+
+/*! \ingroup types_module
+ * \brief rocsparse_sptrsv_descr is a structure holding the rocsparse sptrsv
+ * descr data. It must be initialized using
+ * the rocsparse_create_sptrsv_descr() routine. It should be destroyed at the
+ * end using rocsparse_destroy_sptrsv_descr().
+ */
+typedef struct _rocsparse_sptrsv_descr* rocsparse_sptrsv_descr;
+
+/*! \ingroup types_module
+ * \brief rocsparse_sptrsm_descr is a structure holding the rocsparse sptrsm
+ * descr data. It must be initialized using
+ * the rocsparse_create_sptrsm_descr() routine. It should be destroyed at the
+ * end using rocsparse_destroy_sptrsm_descr().
+ */
+typedef struct _rocsparse_sptrsm_descr* rocsparse_sptrsm_descr;
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -243,10 +305,25 @@ typedef enum rocsparse_index_base_
  *  \brief Specify the matrix type.
  *
  *  \details
- *  The \ref rocsparse_matrix_type indices the type of a matrix. For a given
+ *  The \ref rocsparse_matrix_type indicates the type of a matrix. For a given
  *  \ref rocsparse_mat_descr, the \ref rocsparse_matrix_type can be set using
  *  rocsparse_set_mat_type(). The current \ref rocsparse_matrix_type of a matrix can be
  *  obtained by rocsparse_get_mat_type().
+ *
+ *  For the matrix types \ref rocsparse_matrix_type_symmetric, \ref rocsparse_matrix_type_hermitian,
+ *  and \ref rocsparse_matrix_type_triangular, only the upper or lower part of the matrix
+ *  (specified by setting the \ref rocsparse_fill_mode) is assumed to be stored. The purpose of this
+ *  is to minimize the amount of memory required to store the matrix.
+ *
+ *  Routines that accept \ref rocsparse_matrix_type_symmetric or \ref rocsparse_matrix_type_hermitian
+ *  will only read from the stored upper or lower part of the matrix but will perform the computation
+ *  as if the full symmetric/hermitian matrix existed. For example, when computing \f$y=A*x\f$ where
+ *  A is symmetric and only the lower part is stored, internally the multiplication will be performed
+ *  in two steps. First the computation \f$y=(L+D)*x\f$ will be performed. Secondly the multiplication
+ *  will be completed by performing \f$y=L^T*x + y\f$. This second step involves a transposed
+ *  multiplication which is slower. For this reason, where space allows, it is faster to store the
+ *  entire symmetric matrix and use \ref rocsparse_matrix_type_general instead of
+ *  \ref rocsparse_matrix_type_symmetric.
  */
 typedef enum rocsparse_matrix_type_
 {
@@ -349,9 +426,10 @@ typedef enum rocsparse_hyb_partition_
  *
  *  \details
  *  The \ref rocsparse_analysis_policy specifies whether gathered analysis data should be
- *  re-used or not. If meta data from a previous e.g. rocsparse_csrilu0_analysis() call
- *  is available, it can be re-used for subsequent calls to e.g.
- *  rocsparse_csrsv_analysis() and greatly improve performance of the analysis function.
+ *  re-used or not. If meta data from a previous e.g. \ref rocsparse_scsrilu0_analysis
+ *  "rocsparse_Xcsrilu0_analysis()" call is available, it can be re-used for subsequent calls to e.g.
+ *  \ref rocsparse_scsrsv_analysis "rocsparse_Xcsrsv_analysis()" and greatly improve performance
+ *  of the analysis function.
  */
 typedef enum rocsparse_analysis_policy_
 {
@@ -465,14 +543,16 @@ typedef enum rocsparse_indextype_
  */
 typedef enum rocsparse_datatype_
 {
-    rocsparse_datatype_f32_r = 151, /**< 32 bit floating point, real. */
-    rocsparse_datatype_f64_r = 152, /**< 64 bit floating point, real. */
-    rocsparse_datatype_f32_c = 154, /**< 32 bit floating point, complex. */
-    rocsparse_datatype_f64_c = 155, /**< 64 bit floating point, complex. */
-    rocsparse_datatype_i8_r  = 160, /**<  8-bit signed integer, real */
-    rocsparse_datatype_u8_r  = 161, /**<  8-bit unsigned integer, real */
-    rocsparse_datatype_i32_r = 162, /**< 32-bit signed integer, real */
-    rocsparse_datatype_u32_r = 163 /**< 32-bit unsigned integer, real */
+    rocsparse_datatype_f16_r  = 150, /**< 16 bit floating point, real. */
+    rocsparse_datatype_f32_r  = 151, /**< 32 bit floating point, real. */
+    rocsparse_datatype_f64_r  = 152, /**< 64 bit floating point, real. */
+    rocsparse_datatype_f32_c  = 154, /**< 32 bit floating point, complex. */
+    rocsparse_datatype_f64_c  = 155, /**< 64 bit floating point, complex. */
+    rocsparse_datatype_i8_r   = 160, /**<  8-bit signed integer, real */
+    rocsparse_datatype_u8_r   = 161, /**<  8-bit unsigned integer, real */
+    rocsparse_datatype_i32_r  = 162, /**< 32-bit signed integer, real */
+    rocsparse_datatype_u32_r  = 163, /**< 32-bit unsigned integer, real */
+    rocsparse_datatype_bf16_r = 168 /**< 16-bit brain floating point, real */
 } rocsparse_datatype;
 
 /*! \ingroup types_module
@@ -490,7 +570,8 @@ typedef enum rocsparse_format_
     rocsparse_format_csc     = 3, /**< CSC sparse matrix format. */
     rocsparse_format_ell     = 4, /**< ELL sparse matrix format. */
     rocsparse_format_bell    = 5, /**< BLOCKED ELL sparse matrix format. */
-    rocsparse_format_bsr     = 6 /**< BSR sparse matrix format. */
+    rocsparse_format_bsr     = 6, /**< BSR sparse matrix format. */
+    rocsparse_format_sell    = 7 /**< SLICED ELL sparse matrix format. */
 } rocsparse_format;
 
 /*! \ingroup types_module
@@ -535,7 +616,7 @@ typedef enum rocsparse_sparse_to_sparse_alg_
    *
    *  \details
    *  This is a list of possible stages during sparse_to_sparse conversion. Typical order is
-   *  rocsparse_sparse_to_sparse_buffer_size, rocsparse_sparse_to_sparse_preprocess, rocsparse_sparse_to_sparse_compute.
+   *  \ref rocsparse_sparse_to_sparse_stage_analysis, \ref rocsparse_sparse_to_sparse_stage_compute.
    */
 typedef enum rocsparse_sparse_to_sparse_stage_
 {
@@ -543,6 +624,30 @@ typedef enum rocsparse_sparse_to_sparse_stage_
     rocsparse_sparse_to_sparse_stage_compute  = 1 /**< Performs the actual conversion. */
 } rocsparse_sparse_to_sparse_stage;
 
+/*! \ingroup types_module
+   *  \brief List of extract algorithms.
+   *
+   *  \details
+   *  This is a list of supported \ref rocsparse_extract_alg types that are used to perform
+   *  the submatrix extraction.
+   */
+typedef enum rocsparse_extract_alg_
+{
+    rocsparse_extract_alg_default = 0, /**< Default extract algorithm for the given format. */
+} rocsparse_extract_alg;
+
+/*! \ingroup types_module
+   *  \brief List of extract stages.
+   *
+   *  \details
+   *  The analysis \ref rocsparse_extract_stage_analysis must be done before the first call of the calculation \ref rocsparse_extract_stage_compute.
+   */
+typedef enum rocsparse_extract_stage_
+{
+    rocsparse_extract_stage_analysis = 0, /**< Data analysis. */
+    rocsparse_extract_stage_compute  = 1 /**< Performs the actual extraction. */
+} rocsparse_extract_stage;
+
 /*! \ingroup types_module
  *  \brief List of Iterative ILU0 algorithms.
  *
@@ -559,7 +664,7 @@ typedef enum rocsparse_itilu0_alg_
     = 2, /**< ASynchronous ITILU0 algorithm with explicit storage splitting */
     rocsparse_itilu0_alg_sync_split
     = 3, /**< Synchronous ITILU0 algorithm with explicit storage splitting */
-    rocsparse_itilu0_alg_sync_split_fusion
+    rocsparse_itilu0_alg_sync_split_fusion [[deprecated]]
     = 4 /**< Semi-synchronous ITILU0 algorithm with explicit storage splitting */
 } rocsparse_itilu0_alg;
 
@@ -600,11 +705,11 @@ typedef enum rocsparse_gtsv_interleaved_alg_
 } rocsparse_gtsv_interleaved_alg;
 
 /*! \ingroup types_module
- *  \brief List of check_matrix stages.
+ *  \brief List of check matrix stages.
  *
  *  \details
- *  This is a list of possible stages during check_matrix computation. Typical order is
- *  rocsparse_check_spmat_stage_buffer_size, rocsparse_check_spmat_stage_compute.
+ *  This is a list of possible stages during check matrix computation. Typical order is
+ *  \ref rocsparse_check_spmat_stage_buffer_size, \ref rocsparse_check_spmat_stage_compute.
  */
 typedef enum rocsparse_check_spmat_stage_
 {
@@ -612,12 +717,39 @@ typedef enum rocsparse_check_spmat_stage_
     rocsparse_check_spmat_stage_compute     = 1, /**< Performs check. */
 } rocsparse_check_spmat_stage;
 
+/*! \ingroup types_module
+ *  \brief List of inputs to SpMV descriptor.
+ *
+ *  \details
+ *  This is a list of possible inputs to the SpMV descriptor.
+ */
+typedef enum rocsparse_spmv_input_
+{
+    rocsparse_spmv_input_alg, /**< Select algorithm for input on SpMV descriptor. */
+    rocsparse_spmv_input_operation, /**< Select matrix transpose operation for input on SpMV descriptor. */
+    rocsparse_spmv_input_scalar_datatype, /**< Select scalar  datatype for input on SpMV descriptor. */
+    rocsparse_spmv_input_compute_datatype, /**< Select compute datatype for input on SpMV descriptor. */
+    rocsparse_spmv_input_nnz_use_starting_block_ids
+} rocsparse_spmv_input;
+
+/*! \ingroup types_module
+ *  \brief List of SpMV-Version2 stages.
+ *
+ *  \details
+ *  This is a list of possible stages during SpMV-Version2 computation.
+ */
+typedef enum rocsparse_v2_spmv_stage_
+{
+    rocsparse_v2_spmv_stage_analysis, /**< Analysis of the data. */
+    rocsparse_v2_spmv_stage_compute /**< Performs the actual SpMV computation. */
+} rocsparse_v2_spmv_stage;
+
 /*! \ingroup types_module
  *  \brief List of SpMV stages.
  *
  *  \details
  *  This is a list of possible stages during SpMV computation. Typical order is
- *  rocsparse_spmv_buffer_size, rocsparse_spmv_preprocess, rocsparse_spmv_compute.
+ *  \ref rocsparse_spmv_stage_buffer_size, \ref rocsparse_spmv_stage_preprocess, \ref rocsparse_spmv_stage_compute.
  */
 typedef enum rocsparse_spmv_stage_
 {
@@ -638,11 +770,15 @@ typedef enum rocsparse_spmv_alg_
     rocsparse_spmv_alg_default      = 0, /**< Default SpMV algorithm for the given format. */
     rocsparse_spmv_alg_coo          = 1, /**< COO SpMV algorithm 1 (segmented) for COO matrices. */
     rocsparse_spmv_alg_csr_adaptive = 2, /**< CSR SpMV algorithm 1 (adaptive) for CSR matrices. */
-    rocsparse_spmv_alg_csr_stream   = 3, /**< CSR SpMV algorithm 2 (stream) for CSR matrices. */
+    rocsparse_spmv_alg_csr_rowsplit = 3, /**< CSR SpMV algorithm 2 (rowsplit) for CSR matrices. */
     rocsparse_spmv_alg_ell          = 4, /**< ELL SpMV algorithm for ELL matrices. */
     rocsparse_spmv_alg_coo_atomic   = 5, /**< COO SpMV algorithm 2 (atomic) for COO matrices. */
     rocsparse_spmv_alg_bsr          = 6, /**< BSR SpMV algorithm 1 for BSR matrices. */
-    rocsparse_spmv_alg_csr_lrb      = 7 /**< CSR SpMV algorithm 3 (LRB) for CSR matrices. */
+    rocsparse_spmv_alg_csr_lrb      = 7, /**< CSR SpMV algorithm 3 (LRB) for CSR matrices. */
+    rocsparse_spmv_alg_csr_nnzsplit = 8, /**< CSR SpMV algorithm 4 (nnzsplit) for CSR matrices. */
+    rocsparse_spmv_alg_sell         = 9, /**< SLICED ELL SpMV algorithm for SLICED ELL matrices. */
+    rocsparse_spmv_alg_csr_stream [[deprecated]]
+    = rocsparse_spmv_alg_csr_rowsplit /**< CSR SpMV algorithm 2 (stream) for CSR matrices. */
 } rocsparse_spmv_alg;
 
 /*! \ingroup types_module
@@ -662,7 +798,7 @@ typedef enum rocsparse_spsv_alg_
  *
  *  \details
  *  This is a list of possible stages during SpSV computation. Typical order is
- *  rocsparse_spsv_buffer_size, rocsparse_spsv_preprocess, rocsparse_spsv_compute.
+ *  \ref rocsparse_spsv_stage_buffer_size, \ref rocsparse_spsv_stage_preprocess, \ref rocsparse_spsv_stage_compute.
  */
 typedef enum rocsparse_spsv_stage_
 {
@@ -688,7 +824,7 @@ typedef enum rocsparse_spitsv_alg_
  *
  *  \details
  *  This is a list of possible stages during SpITSV computation. Typical order is
- *  buffer_size, preprocess, compute.
+ *  \ref rocsparse_spitsv_stage_buffer_size, \ref rocsparse_spitsv_stage_preprocess, \ref rocsparse_spitsv_stage_compute.
  */
 typedef enum rocsparse_spitsv_stage_
 {
@@ -714,7 +850,7 @@ typedef enum rocsparse_spsm_alg_
  *
  *  \details
  *  This is a list of possible stages during SpSM computation. Typical order is
- *  rocsparse_spsm_buffer_size, rocsparse_spsm_preprocess, rocsparse_spsm_compute.
+ *  \ref rocsparse_spsm_stage_buffer_size, \ref rocsparse_spsm_stage_preprocess, \ref rocsparse_spsm_stage_compute.
  */
 typedef enum rocsparse_spsm_stage_
 {
@@ -790,7 +926,7 @@ typedef enum rocsparse_dense_to_sparse_alg_
  *
  *  \details
  *  This is a list of possible stages during SpMM computation. Typical order is
- *  rocsparse_spmm_buffer_size, rocsparse_spmm_preprocess, rocsparse_spmm_compute.
+ *  \ref rocsparse_spmm_stage_buffer_size, \ref rocsparse_spmm_stage_preprocess, \ref rocsparse_spmm_stage_compute.
  */
 typedef enum rocsparse_spmm_stage_
 {
@@ -804,7 +940,7 @@ typedef enum rocsparse_spmm_stage_
  *
  *  \details
  *  This is a list of possible stages during SpGEMM computation. Typical order is
- *  rocsparse_spgemm_buffer_size, rocsparse_spgemm_nnz, rocsparse_spgemm_compute.
+ *  \ref rocsparse_spgemm_stage_buffer_size, \ref rocsparse_spgemm_stage_nnz, \ref rocsparse_spgemm_stage_compute.
  */
 typedef enum rocsparse_spgemm_stage_
 {
@@ -827,6 +963,171 @@ typedef enum rocsparse_spgemm_alg_
     rocsparse_spgemm_alg_default = 0 /**< Default SpGEMM algorithm for the given format. */
 } rocsparse_spgemm_alg;
 
+/*! \ingroup types_module
+ *  \brief List of SpTRSV algorithms.
+ *
+ *  \details
+ *  This is a list of supported \ref rocsparse_sptrsv_alg types that are used to perform
+ *  triangular solve.
+ */
+typedef enum rocsparse_sptrsv_alg_
+{
+    rocsparse_sptrsv_alg_default = 0, /**< Default SpTRSV algorithm for the given format. */
+} rocsparse_sptrsv_alg;
+
+/*! \ingroup types_module
+ *  \brief List of SpTRSV stages.
+ *
+ *  \details
+ *  This is a list of possible stages during SpTRSV computation.
+ */
+typedef enum rocsparse_sptrsv_stage_
+{
+    rocsparse_sptrsv_stage_analysis, /**< Analysis. */
+    rocsparse_sptrsv_stage_compute /**< Performs the actual SpTRSV computation. */
+} rocsparse_sptrsv_stage;
+
+/*! \ingroup types_module
+ *  \brief List of inputs to SpTRSV descriptor.
+ *
+ *  \details
+ *  This is a list of possible inputs to the SpTRSV descriptor.
+ */
+typedef enum rocsparse_sptrsv_input_
+{
+    rocsparse_sptrsv_input_alg, /**< Select algorithm \ref rocsparse_sptrsv_alg for input on SpTRSV descriptor. */
+    rocsparse_sptrsv_input_operation, /**< Select matrix operation \ref rocsparse_operation for input on SpTRSV descriptor. */
+    rocsparse_sptrsv_input_scalar_datatype, /**< Select scalar datatype \ref rocsparse_datatype for input on SpTRSV descriptor. */
+    rocsparse_sptrsv_input_compute_datatype, /**< Select compute datatype  \ref rocsparse_datatype for input on SpTRSV descriptor. */
+    rocsparse_sptrsv_input_scalar_alpha, /**< Select scalar alpha pointer for input on SpTRSV descriptor. */
+    rocsparse_sptrsv_input_analysis_policy /**< Select the analysis policy  \ref rocsparse_analysis_policy for input on SpTRSV descriptor. */
+} rocsparse_sptrsv_input;
+
+/*! \ingroup types_module
+ *  \brief List of outputs to SpTRSV descriptor.
+ *
+ *  \details
+ *  This is a list of possible outputs to the SpTRSV descriptor.
+ */
+typedef enum rocsparse_sptrsv_output_
+{
+    rocsparse_sptrsv_output_zero_pivot_position /**< Get zero pivot int64_t based position for output from SpTRSV descriptor. */
+} rocsparse_sptrsv_output;
+
+/*! \ingroup types_module
+ *  \brief List of SpTRSM algorithms.
+ *
+ *  \details
+ *  This is a list of supported \ref rocsparse_sptrsm_alg types that are used to perform
+ *  triangular solve.
+ */
+typedef enum rocsparse_sptrsm_alg_
+{
+    rocsparse_sptrsm_alg_default = 0, /**< Default SpTRSM algorithm for the given format. */
+} rocsparse_sptrsm_alg;
+
+/*! \ingroup types_module
+ *  \brief List of SpTRSM stages.
+ *
+ *  \details
+ *  This is a list of possible stages during SpTRSM computation.
+ */
+typedef enum rocsparse_sptrsm_stage_
+{
+    rocsparse_sptrsm_stage_analysis, /**< Analysis. */
+    rocsparse_sptrsm_stage_compute /**< Performs the actual SpTRSM computation. */
+} rocsparse_sptrsm_stage;
+
+/*! \ingroup types_module
+ *  \brief List of inputs to SpTRSM descriptor.
+ *
+ *  \details
+ *  This is a list of possible inputs to the SpTRSM descriptor.
+ */
+typedef enum rocsparse_sptrsm_input_
+{
+    rocsparse_sptrsm_input_alg, /**< Select algorithm \ref rocsparse_sptrsm_alg for input on SpTRSM descriptor. */
+    rocsparse_sptrsm_input_operation_A, /**< Select matrix A operation \ref rocsparse_operation for input on SpTRSM descriptor. */
+    rocsparse_sptrsm_input_operation_X, /**< Select matrix X operation \ref rocsparse_operation  for input on SpTRSM descriptor. */
+    rocsparse_sptrsm_input_compute_datatype, /**< Select compute datatype \ref rocsparse_datatype for input on SpTRSM descriptor. */
+    rocsparse_sptrsm_input_scalar_datatype, /**< Select scalar datatype \ref rocsparse_datatype for input on SpTRSM descriptor. */
+    rocsparse_sptrsm_input_scalar_alpha, /**< Select scalar alpha pointer for input on SpTRSM descriptor, this datatype is used as the compute type. */
+    rocsparse_sptrsm_input_analysis_policy /**< Select the analysis policy \ref rocsparse_analysis_policy for input on SpTRSM descriptor */
+
+} rocsparse_sptrsm_input;
+
+/*! \ingroup types_module
+ *  \brief List of outputs to SpTRSM descriptor.
+ *
+ *  \details
+ *  This is a list of possible outputs to the SpTRSM descriptor.
+ */
+typedef enum rocsparse_sptrsm_output_
+{
+    rocsparse_sptrsm_output_zero_pivot_position /**< Get zero pivot int64_t based position for output from SpTRSM descriptor. */
+} rocsparse_sptrsm_output;
+
+/*! \ingroup types_module
+ *  \brief List of SpGEAM stages.
+ *
+ *  \details
+ *  This is a list of possible stages during SpGEAM computation. Typical order is
+ *  rocsparse_spgeam_stage_buffer_size, rocsparse_spgeam_stage_analysis, rocsparse_spgeam_stage_compute.
+ */
+typedef enum rocsparse_spgeam_stage_
+{
+    rocsparse_spgeam_stage_analysis = 1, /**< Computes number of non-zero entries. */
+    rocsparse_spgeam_stage_compute  = 2, /**< Performs the actual SpGEAM computation. */
+    rocsparse_spgeam_stage_symbolic_analysis
+    = 3, /**< Performs only the symbolic analysis SpGEAM computation to fill the column indices array. */
+    rocsparse_spgeam_stage_symbolic_compute
+    = 4, /**< Performs only the symbolic SpGEAM computation to fill the column indices array. */
+    rocsparse_spgeam_stage_numeric_analysis
+    = 5, /**< Performs only the numeric analysis SpGEAM computation to fill the values array. */
+    rocsparse_spgeam_stage_numeric_compute
+    = 6 /**< Performs only the numeric SpGEAM computation to fill the values array. */
+} rocsparse_spgeam_stage;
+
+/*! \ingroup types_module
+ *  \brief List of inputs to SpGEAM descriptor.
+ *
+ *  \details
+ *  This is a list of possible inputs to the SpGEAM descriptor.
+ */
+typedef enum rocsparse_spgeam_input_
+{
+    rocsparse_spgeam_input_alg, /**< Select algorithm for input on SpGEAM descriptor. */
+    rocsparse_spgeam_input_scalar_datatype, /**< Select scalar data type for input on SpGEAM descriptor. */
+    rocsparse_spgeam_input_compute_datatype, /**< Select compute data type for input on SpGEAM descriptor. */
+    rocsparse_spgeam_input_operation_A, /**< Select A matrix transpose operation for input on SpGEAM descriptor. */
+    rocsparse_spgeam_input_operation_B, /**< Select B matrix transpose operation for input on SpGEAM descriptor. */
+    rocsparse_spgeam_input_scalar_alpha, /**< Select scalar multiplier alpha for input on SpGEAM descriptor. */
+    rocsparse_spgeam_input_scalar_beta /**< Select scalar multiplier beta for input on SpGEAM descriptor. */
+} rocsparse_spgeam_input;
+
+/*! \ingroup types_module
+ *  \brief List of outputs to SpGEAM descriptor.
+ *
+ *  \details
+ *  This is a list of possible outputs to the SpGEAM descriptor.
+ */
+typedef enum rocsparse_spgeam_output_
+{
+    rocsparse_spgeam_output_nnz /**< Select nnz count for output from SpGEAM descriptor. */
+} rocsparse_spgeam_output;
+
+/*! \ingroup types_module
+ *  \brief List of SpGEAM algorithms.
+ *
+ *  \details
+ *  This is a list of supported \ref rocsparse_spgeam_alg types that are used to perform
+ *  sparse matrix sparse matrix product.
+ */
+typedef enum rocsparse_spgeam_alg_
+{
+    rocsparse_spgeam_alg_default = 0 /**< Default SpGEAM algorithm for the given format. */
+} rocsparse_spgeam_alg;
+
 /*! \ingroup types_module
  *  \brief List of gpsv algorithms.
  *
